/** The configuration of SER for working with JSON */
export interface ISerConfig {
    /** All tasks to be performed */
    tasks: ISerTask[];
}
/** Authentication type to connect to Qlik */
export declare enum QlikCredentialType {
    /** Connection without Authentication */
    NONE = 0,
    /** Authentication over Windows user name and password */
    WINDOWSAUTH = 1,
    /** Authentication over Qlik client certificate */
    CERTIFICATE = 2,
    /** Authentication over Qlik session cookie */
    SESSION = 3,
    /** Authentication over Vitrual Proxy with method JWT */
    JWT = 4,
    /** Authentication over Vitrual Proxy with JWT Bearer */
    HEADER = 5
}
/** Qlik authentication type */
export interface IQlikCredentials {
    /** Qlik authentication type */
    type: QlikCredentialType;
}
/** Logic for certificate authentication */
export interface ICertificateAuth extends IQlikCredentials {
    /** Path to the qlik server certificates */
    certificatePath: string;
    /** Qlik UserId */
    userId: string;
    /** Qlik UserDirectory */
    userDirectory: string;
    /** Password of the certificate which can be specified when generating */
    certPassword: string;
}
/** The Session authentication class */
export interface ISessionAuth extends IQlikCredentials {
    /** The name of the cookie (Default: XQlik-Session) */
    cookieName: string;
    /** The value of the cookie */
    cookieValue: string;
}
/** Type of the email body */
export declare enum EMailType {
    /** Use mail plain text in the mail body */
    TEXT = 0,
    /** Use html code in the mail body */
    HTML = 1,
    /** Use markdown syntax in the mail body */
    MARKDOWN = 2
}
/** Distribute type */
export declare enum SettingsType {
    /** Distribute type mail */
    MAIL = 0,
    /** Distribute type file */
    FILE = 1,
    /** Distribute type hub */
    HUB = 2
}
/** Mode how the delivery should behave. */
export declare enum DistributeMode {
    /** Override the content or file on distribute. */
    OVERRIDE = 0,
    /** Delete all content before distribute */
    DELETEALLFIRST = 1,
    /** Create only new content or trigger an exception. */
    CREATEONLY = 2
}
/** Basic interfaces to identify the delivery type */
export interface ISettings {
    /** The type of the settings */
    type: SettingsType;
    /** Activate distribute */
    active: boolean;
}
/** Base settings */
export interface IBaseDeliverySettings extends ISettings {
    /** Activate distribute */
    active: boolean;
    /** Distribute type */
    type: SettingsType;
}
/** Base setting for distribute */
export interface IDeliverySettings extends ISettings, IBaseDeliverySettings {
    /** target location for distribute */
    target: string;
    /** distribute mode */
    mode: DistributeMode;
    /** The user to be the owner. */
    owner: string;
    /** All connections that can be used. */
    connections: ISerConnection[];
}
/** The settings for file distribute */
export interface IFileSettings extends ISettings, IDeliverySettings {
}
/** The settings for hub distribute */
export interface IHubSettings extends ISettings, IDeliverySettings {
    /** The content type of the report. */
    sharedContentType: string;
}
/** The settings for mail distribute */
export interface IMailSettings extends ISettings, IBaseDeliverySettings {
    /** The subject of the mail */
    subject: string;
    /** The message of the mail */
    message: string;
    /** The body type of the mail */
    mailType: EMailType;
    /** The recipients of the email */
    to: string;
    /** The copy recipients of the email */
    cc: string;
    /** The blind copy recipients of the email */
    bcc: string;
    /** The mail server settings */
    mailServer: IMailServerSettings;
    /** List of Reportpaths */
    paths: string[];
    /** Name of the report */
    reportName: string;
}
/** The settings of the mail server. */
export interface IMailServerSettings {
    /** The host machine */
    host: string;
    /** The sender of the mail */
    from: string;
    /** The port of the mail server */
    port: number;
    /** The username of the mail account */
    username: string;
    /** The password of the mail account */
    password: string;
    /** Use ssl of authentication */
    useSsl: boolean;
}
/** Class for work with the qlik userid und userdirectory logic. */
export interface IDomainUser {
    /** Qlik user id */
    userId: string;
    /** Qlik user directory */
    userDirectory: string;
}
/** The status of a finished script */
export declare enum ScriptResult {
    /** Unkown result */
    UNKOWN = 0,
    /** Success result */
    SUCCESS = 1,
    /** The .net script has an error */
    SCRIPT_ERROR = 2,
    /** No access to the sandbox. */
    PERMISSION_ERROR = 3,
    /** General error */
    ERROR = 4,
    /** General warning */
    WARNING = 5
}
/** The stauts of a finished task */
export declare enum TaskStatusInfo {
    /** The Task was abort */
    ABORT = 0,
    /** The Task was finished successfull */
    SUCCESS = 1,
    /** The Task was finished with warnings */
    WARNING = 2,
    /** The Task was finished with an error */
    ERROR = 3,
    /** The Task was finished with an error, but is repeated at the next call */
    RETRYERROR = 4
}
/**
* The result of a finished job.
*             This information is needed for the result file.
*/
export interface IJobResult {
    /** The id of the task. */
    taskId: any;
    /** The start time of the task. */
    startTime: any;
    /** The runtime of the task. */
    runTime: any;
    /** The status information of the finished task */
    status: TaskStatusInfo;
    /** The current version of aspose cells. */
    asposeVersion: string;
    /** The current version of the ser engine. */
    engineVersion: string;
    /** The count of the reports. */
    count: number;
    /** The list of the generated reports. */
    reports: IReport[];
}
/**
* This class is a part of JobResult.
*             It maps the individual report in the job result.
*/
export interface IReport {
    /** The individually name of the report. */
    name: string;
    /**
    * The path or paths of the Report.
    *             The PDF can save multiple pages, in this case is it one path.
    *             The CSV save multiple files, in this case is it many paths.
    */
    paths: string[];
    /** The list of script results that were executed before the calculation was running. */
    preScriptResult: ScriptResult[];
    /** The list of script results that were executed after the calculation was running. */
    afterScriptResult: ScriptResult[];
    /** The used connection to create the report. */
    connection: ISerConnection;
}
/** The type of the selection */
export declare enum SelectionType {
    /** Use a fixed filter name or bookmark. */
    Static = 0,
    /** Loop over a field or dimension. */
    Dynamic = 1
}
/** The full task object and configuration. */
export interface ISerTask {
    /** The reports to be generating. */
    reports: ISerReport[];
}
/** The report of the ser task. */
export interface ISerReport {
    /** The general setting of a report. */
    general: ISerGeneral;
    /** The template of a report. */
    template: ISerTemplate;
    /** The available connections to Qlik. */
    connections: ISerConnection[];
}
/** The general settings for the report. */
export interface ISerGeneral {
    /** The time after clean up the temp folder. */
    cleanupTimeOut?: number;
    /** The time until the report is aborted. */
    timeout?: number;
    /** The repeat until the report is canceled as error. */
    errorRepeatCount?: number;
    /** Use the sand box for script execute. */
    useSandbox?: boolean;
    /** The count of cpus or cpu cores for the ser engine. */
    cpuLimitInCore?: number;
    /** The soft memory limit for the ser engine. */
    memoryLimitInGB?: number;
}
/** The template for the report. */
export interface ISerTemplate {
    /**
    * The Input path of the template.
    *             You can use the protokoll 'content' or 'lib'
    *             Samples:
    *             Use 'content:///[TEMPLATE]' for InApp template
    *             Use 'content://[CONTENTLIBARY]/[TEMPLATE]' for a content libary.
    *             Use 'lib://[LIB-FOLDER]/[TEMPLATE]' for a special folder.
    */
    input: string;
    /**
    * The output name of the report.
    *             Note:
    *             You can use the output name with or without file extention.
    *             If you use the output name without a file extension, you must also use the property 'Outputformat'.
    *             If you do not specify a file extension, PDF will be used automatically.
    */
    output: string;
    /**
    * The file extention for the output name.
    *             It is optional.
    */
    outputFormat?: string;
    /**
    * The password what should be set for the reports.
    *             Note:
    *             It only works for PDF and XLSX files.
    *             If you not want the password remove it in the json.
    *             Please do not leave blank, because the human json convention can not handle it.
    */
    outputPassword?: string;
    /** Save the formula as json in the template */
    keepFormula?: boolean;
    /** The signature for the script executing. */
    scriptKeys?: string[];
    /** The arguments for the executing .NET scripts */
    scriptArgs?: string[];
    /** The qlik filters used for the report. */
    selections?: ISerSenseSelection[];
    /**
    * Clear or clear not the Qlik selections in a session.
    *             This mode is importent for the OnDemand Extention.
    */
    selectionsClearAll?: boolean;
}
/** The credentials for the report. */
export interface ISerCredentials {
    /** The credential type for the connection. */
    type: QlikCredentialType;
    /** The name of the cookie. */
    key: string;
    /** The Value of the cookie. */
    value: string;
    /** The path to the JWT certificate. */
    cert?: string;
    /**
    * The path to the private key.
    *             It's generate the JWT token.
    */
    privateKey?: string;
}
/** The connection class of the report. */
export interface ISerConnection {
    /**
    * The Connection uri to Qlik.
    *             Note:
    *             Desktop: "Qlik Sense Desktop"
    *             Server: "https://NAME_OF_SERVER/VIRTUALPROXY"
    */
    serverUri?: string;
    /** Qlik app name or id */
    app: string;
    /**
    * The reload timeout for InAppMode.
    *             Wait for data reload of the app.
    *             Wait for other apps or processes
    */
    retryTimeout?: number;
    /** Use the ssl validation */
    sslVerify?: boolean;
    /** The thumb print from qlik client ssl certificate. */
    sslValidThumbprints?: ISerThumbprint[];
    /** Share the qlik session or create a new session with a identity */
    identities?: string[];
    /** The credentials for the qlik communication. */
    credentials?: ISerCredentials;
    /** The lisence keys */
    lefs?: string[];
}
/**
* The thumb print for the report.
*             Note:
*             Copy the thumb print from thw qlik client certificate.
*/
export interface ISerThumbprint {
    /** The server url to the qlilk certificate */
    url: string;
    /** The thumb print from the qlik clint certificate */
    thumbprint: string;
}
/** The selection of the report. */
export interface ISerSenseSelection {
    /** The Name of the filter. */
    name?: string;
    /**
    * Type of the filter type.
    *             By Default it will used 'Field'.
    *             Other Values are 'bookmark' and 'hiddenbookmark'
    */
    objectType?: string;
    /** The values that should be used. */
    values?: string[];
    /** Type of the selection. */
    type?: SelectionType;
    /** Export a Root node for the sheet names. */
    exportRootNode?: boolean;
    /**
    * Give the sheet a seperate sheet name form a formaula
    *             You can also use @@sheetname@@ as placeholter for the orignal sheet name.
    */
    sheetName?: string;
}
